@@ -1247,14 +1247,52 @@ class OpenBatchJournal(Wizard):
         return 'ask'
 
     def do_open_(self, action):
+        pool = Pool()
+        Company = pool.get('company.company')
+        Translation = pool.get('ir.translation')
+
         batch_journal = self.ask.batch_journal
         batch = self.ask.batch
         fiscalyear = self.ask.fiscalyear
         period = self.ask.period
 
-        # Use name from view_header_get
-        del action['name']
-        del action['rec_name']
+        context = Transaction().context
+        lang_code = 'en'
+        if context.get('company'):
+            company = Company(context['company'])
+            if company.party.lang:
+                lang_code = company.party.lang.code
+
+        def get_translated_item(source, model, lang_code):
+            return (Translation.get_source(model, 'field', lang_code, source)
+                or source)
+
+        batch_string = journal_string = period_string = year_string = ''
+        if batch_journal:
+            trans_journal = get_translated_item('Journal',
+                'account.batch.line,journal', lang_code)
+            journal_string = '%s: %s' % (trans_journal, batch_journal.rec_name)
+        if batch:
+            trans_batch = get_translated_item('Batch',
+                'account.batch.line,batch', lang_code)
+            batch_string = '%s: %s' % (trans_batch, batch.name)
+        if period:
+            trans_period = get_translated_item('Period',
+                'account.journal.period,period', lang_code)
+            period_string = '%s: %s' % (trans_period, period.name)
+        elif fiscalyear:
+            trans_fiscalyear = get_translated_item('Fiscal Year',
+                'account.batch.line,fiscalyear', lang_code)
+            year_string = '%s: %s' % (trans_fiscalyear, fiscalyear.name)
+        title = ' | '.join([_f for _f in [
+            batch_string,
+            journal_string,
+            period_string,
+            year_string] if _f])
+        if self.ask.show_posted:
+            title += ' (*)'
+        action['name'] = title
+        action['rec_name'] = title
 
         domain = []
         ctx = {}
@@ -1281,13 +1319,6 @@ class OpenBatchJournal(Wizard):
             domain.append(('fiscalyear.id', '=', fiscalyear.id))
             ctx['fiscalyear'] = fiscalyear.id
 
-        if not action.get('name'):
-            action['name'] = ''
-        header_suffix = ''
-        if self.ask.show_posted:
-            header_suffix += ' (*)'
-        ctx['header_suffix'] = header_suffix
-
         action['pyson_domain'] = PYSONEncoder().encode(domain)
         action['pyson_context'] = PYSONEncoder().encode(ctx)
 
